@@ -28,23 +28,22 @@ import json
 import socket
 import os
 import re
-import ssl as _ssl
+
 import threading
 import asyncio
 
 from asyncio.base_events import Server
 from asyncio.streams import StreamReader, StreamWriter
-
+from ssl import PROTOCOL_TLS_SERVER, SSLContext
 from collections import OrderedDict
 from socketserver import ThreadingMixIn, TCPServer
 from time import sleep
-from urllib.parse import unquote
-from urllib.parse import quote
+from urllib.parse import unquote, quote
 
 from typing import Callable, Dict, List, Tuple
 
 from simple_http_server import ControllerFunction, StaticFile
-from simple_http_server.http_protocol_handler import HttpProtocolHandler, SocketServerStreamRequestHandlerWraper
+from .http_protocol_handler import HttpProtocolHandler, SocketServerStreamRequestHandlerWraper
 from .wsgi_request_handler import WSGIRequestHandler
 
 from .__utils import remove_url_first_slash, get_function_args, get_function_kwargs
@@ -116,8 +115,29 @@ class RoutingConf:
         _url: str = url
         path_names = re.findall("(?u)\\{\\w+\\}", _url)
         if len(path_names) == 0:
-            # normal url
-            return None, path_names
+            if _url.startswith("**"):
+                _url = _url[2: ]
+                assert _url.find("*") < 0, "You can only config a * or ** at the start or end of a path."
+                _url = f'^([\\w%.-@!\\(\\)\\[\\]\\|\\$/]+){_url}$'
+                return _url, [quote("__path_wildcard")]
+            elif _url.startswith("*"):
+                _url = _url[1: ]
+                assert _url.find("*") < 0, "You can only config a * or ** at the start or end of a path."
+                _url = f'^([\\w%.-@!\\(\\)\\[\\]\\|\\$]+){_url}$'
+                return _url, [quote("__path_wildcard")]
+            elif _url.endswith("**"):
+                _url = _url[0: -2]
+                assert _url.find("*") < 0, "You can only config a * or ** at the start or end of a path."
+                _url = f'^{_url}([\\w%.-@!\\(\\)\\[\\]\\|\\$/]+)$'
+                return _url, [quote("__path_wildcard")]
+            elif _url.endswith("*"):
+                _url = _url[0: -1]
+                assert _url.find("*") < 0, "You can only config a * or ** at the start or end of a path."
+                _url = f'^{_url}([\\w%.-@!\\(\\)\\[\\]\\|\\$]+)$'
+                return _url, [quote("__path_wildcard")]
+            else:
+                # normal url
+                return None, path_names
         for name in path_names:
             _url = _url.replace(name, "([\\w%.-@!\\(\\)\\[\\]\\|\\$]+)")
         _url = f"^{_url}$"
@@ -384,16 +404,15 @@ class ThreadingMixInHTTPServer(ThreadingMixIn, HTTPServer):
 
 class CoroutineHTTPServer(RoutingConf):
 
-    def __init__(self, host: str = '', port: int = 9090, ssl: _ssl.SSLContext = None, res_conf={}) -> None:
+    def __init__(self, host: str = '', port: int = 9090, ssl: SSLContext = None, res_conf={}) -> None:
         RoutingConf.__init__(self, res_conf)
         self.host: str = host
         self.port: int = port
-        self.ssl: _ssl.SSLContext = ssl
+        self.ssl: SSLContext = ssl
         self.server: Server = None
 
     async def callback(self, reader: StreamReader, writer: StreamWriter):
         handler = HttpProtocolHandler(reader, writer, routing_conf=self)
-        handler.coroutine = True
         await handler.handle_request()
         _logger.debug("Connection ends, close the writer.")
         writer.close()
@@ -448,12 +467,12 @@ class SimpleDispatcherHttpServer:
     def __init__(self,
                  host: Tuple[str, int] = ('', 9090),
                  ssl: bool = False,
-                 ssl_protocol: int = _ssl.PROTOCOL_TLS_SERVER,
+                 ssl_protocol: int = PROTOCOL_TLS_SERVER,
                  ssl_check_hostname: bool = False,
                  keyfile: str = "",
                  certfile: str = "",
                  keypass: str = "",
-                 ssl_context: _ssl.SSLContext = None,
+                 ssl_context: SSLContext = None,
                  resources: Dict[str, str] = {},
                  prefer_corountine=False):
         self.host = host
@@ -466,7 +485,7 @@ class SimpleDispatcherHttpServer:
                 self.ssl_ctx = ssl_context
             else:
                 assert keyfile and certfile, "keyfile and certfile should be provided. "
-                ssl_ctx = _ssl.SSLContext(protocol=ssl_protocol)
+                ssl_ctx = SSLContext(protocol=ssl_protocol)
                 ssl_ctx.check_hostname = ssl_check_hostname
                 ssl_ctx.load_cert_chain(
                     certfile=certfile, keyfile=keyfile, password=keypass)
@@ -475,9 +494,11 @@ class SimpleDispatcherHttpServer:
             self.ssl_ctx = None
 
         if prefer_corountine:
+            _logger.info(f"Start server in corouting mode, listen to port: {self.host[1]}")
             self.server = CoroutineHTTPServer(
                 self.host[0], self.host[1], self.ssl_ctx, resources)
         else:
+            _logger.info(f"Start server in threading mixed mode, listen to port {self.host[1]}")
             self.server = ThreadingMixInHTTPServer(self.host, resources)
             if self.ssl_ctx:
                 self.server.socket = self.ssl_ctx.wrap_socket(
